# eric7.Testing.Interfaces

Package containg the various test framework interfaces.

### Modules

PytestExecutor | Module implementing the executor for the 'pytest' framework.
PytestRunner | Module implementing the test runner script for the 'pytest' framework.
TestExecutorBase | Module implementing the executor base class for the various testing frameworks and supporting classes.
TestFrameworkRegistry | Module implementing a simple registry containing the available test framework interfaces.
UnittestExecutor | Module implementing the executor for the standard 'unittest' framework.
UnittestRunner | Module implementing the test runner script for the 'unittest' framework.